@@ -54,7 +54,7 @@ class monday_endpoints:
                     raise Exception("Error: " + request.json()['error_data'])
                 else:
                     break
-            logging.info('Request: ' + str(request.json()))
+            logging.debug('Request: ' + str(request.json()))
             if 'query' in body and not "me" in request.json()['data'].keys() and not "account" in request.json()['data'].keys():
                 data_in_request = self.get_data(request.json())
                 dataList.extend(data_in_request)
